==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/quercus/src/com/caucho/quercus/env/SessionVar.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.quercus.env;

import com.caucho.quercus.QuercusModuleException;

/**
 * Represents a PHP variable value.
 */
public class SessionVar extends Var {
  /**
   * Sets the value.
   */
  public Value set(Value value)
  {
    if (value instanceof SessionArrayValue) {
      return super.set(value);
    }
    else if (value instanceof ArrayValue) {
      ArrayValue arrayValue = (ArrayValue) value;
      ArrayValue sessionValue = (ArrayValue) getRawValue();

      sessionValue.clear();

      sessionValue.putAll(arrayValue);

      return value;
    }
    else if (! value.isset()) {
      return super.set(value);
    }
    else
      throw new QuercusModuleException(L.l("Can't set this variable"));
  }

  /**
   * Sets the value.
   */
  protected Value setRaw(Value value)
  {
    throw new QuercusModuleException(L.l("Can't set this variable"));
  }
}

==> resin-4.0.32-src.tar.gz: resin-4.0.32/modules/quercus/src/com/caucho/quercus/env/SessionVar.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.quercus.env;

import com.caucho.quercus.QuercusModuleException;

/**
 * Represents a PHP variable value.
 */
public class SessionVar extends Var
{
  /**
   * Sets the value.
   */
  public Value set(Value value)
  {
    if (value instanceof SessionArrayValue) {
      super.set(value);
      
      return value;
    }
    else if (value instanceof ArrayValue) {
      ArrayValue arrayValue = (ArrayValue) value;
      ArrayValue sessionValue = (ArrayValue) toValue();

      sessionValue.clear();

      sessionValue.putAll(arrayValue);

      return value;
    }
    else if (! value.isset()) {
      super.set(value);
      
      return value;
    }
    else
      throw new QuercusModuleException(L.l("Can't set this variable"));
  }

  /**
   * Sets the value.
   */
  protected Value setRaw(Value value)
  {
    throw new QuercusModuleException(L.l("Can't set this variable"));
  }
}
